@@ -28,7 +28,7 @@ namespace KDebugSettingsUtil
 void readLoggingCategories(const QString &filename, Category::List &categoriesList, bool checkCategoryList = false);
 Category::List readLoggingQtCategories(const QString &filename);
 Category parseLineKdeLoggingCategory(QString line);
-Category parseLineLoggingQtCategory(QString line);
+Category parseLineLoggingQtCategory(const QString &line);
 Category::List readLoggingCategoriesForInserting(const QString &filename, Category::List &categoriesList);
 }
 
